@@ -2,7 +2,7 @@
    Project: LaternaMagica
    AppController.m
 
-   Copyright (C) 2006-2010 Riccardo Mottola
+   Copyright (C) 2006-2012 Riccardo Mottola
 
    Author: Riccardo Mottola
 
@@ -23,9 +23,23 @@
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
+#if !defined (GNUSTEP) &&  (MAC_OS_X_VERSION_MAX_ALLOWED <= MAC_OS_X_VERSION_10_4)
+#define NSInteger int
+#endif
+
+#if defined(__MINGW__)
+#define srandom srand
+#define random rand
+#endif
+
+#include <stdlib.h>
+#include <time.h>
+
 #import "AppController.h"
 #import "PRScale.h"
 
+#define LM_KEY_DESTROYRECYCLE @"DestroyOrRecycle"
+#define LM_KEY_ASKDELETING @"AskBeforeDeleting"
 
 @implementation AppController
 
@@ -33,10 +47,13 @@
 {
     if ((self = [super init]))
     {
-        // add an observer for the file table view
-        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(_selectionDidChange:) name:NSTableViewSelectionDidChangeNotification object:fileListView];
-        // add an observer for the window resize
-        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(_windowDidResize:) name:NSWindowDidResizeNotification object:window];
+      /* add an observer for the file table view */
+      [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(_selectionDidChange:) name:NSTableViewSelectionDidChangeNotification object:fileListView];
+      /* add an observer for the window resize */
+      [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(_windowDidResize:) name:NSWindowDidResizeNotification object:window];
+
+      /* initialize random number generator */
+      srandom(time(NULL));
     }
     return self;
 }
@@ -324,6 +341,29 @@
     }    
 }
 
+- (IBAction)removeAllImages:(id)sender
+{
+  int rows;
+  int i;
+  
+  rows = [fileListView numberOfRows];
+  for (i = ([fileListView numberOfRows]  - 1); i >= 0 ; i--)
+    [fileListData removeObjectAtIndex: i];
+  [fileListView reloadData];
+  [view setImage: nil];
+  [window setTitle:@"None"];
+}
+
+- (IBAction)scrambleList:(id)sender
+{
+  [fileListData scrambleObjects];
+  [fileListView reloadData];
+  
+  /* we reload the image directly without calling selectRow,
+     the selected row did not actually change and no notification triggers */
+  [self changeImage: [fileListData pathAtIndex: [fileListView selectedRow]]];
+}
+
 - (IBAction)removeImage:(id)sender
 {
     int sr;
@@ -361,20 +401,51 @@
 
 - (IBAction)eraseImage:(id)sender
 {
-    int sr;
-    
-    sr = [fileListView selectedRow];
-    if (sr >= 0)
-        if (NSRunAlertPanel(nil, @"Really delete the image from disk?", @"Delete", @"Abort", nil) == NSAlertDefaultReturn)
-        {
-            NSFileManager *fm;
+  int sr;
+  BOOL shallErase;
+  NSUserDefaults *defaults;
+  
+  defaults = [NSUserDefaults standardUserDefaults];
+  sr = [fileListView selectedRow];
+  if (sr >= 0)
+    {
+      if ([defaults boolForKey:LM_KEY_ASKDELETING])
+	{
+	  int result;
+
+	  result = NSRunAlertPanel(nil, @"Really delete the image from disk?", @"Delete", @"Abort", nil);
+	  shallErase = NO;
+	  if (result == NSAlertDefaultReturn)
+	    shallErase = YES;
+	}
+      else
+	shallErase = YES;
+      if (shallErase)
+	{
+	  NSWorkspace *ws;
+	  NSString *fileOperation;
+	  int opTag;
+	  NSString *folder;
+	  NSString *file;
+
+	  if ([defaults boolForKey:LM_KEY_DESTROYRECYCLE])
+	    fileOperation = NSWorkspaceDestroyOperation;
+	  else
+	    fileOperation = NSWorkspaceRecycleOperation;
+
+	  folder = [[fileListData pathAtIndex:sr]stringByDeletingLastPathComponent];
+	  file = [[fileListData pathAtIndex:sr] lastPathComponent];
+	  ws = [NSWorkspace sharedWorkspace];
+	  opTag = 1;
+	  [ws performFileOperation:fileOperation
+			    source:folder
+		       destination:nil
+			     files:[NSArray arrayWithObject: file]
+			       tag:&opTag];
             
-            fm = [NSFileManager defaultManager];
-            // TODO should implement a handler and error messages
-            [fm removeFileAtPath:[fileListData pathAtIndex:sr] handler:nil];
-            
-            [self removeImage:self];
-        }
+	  [self removeImage:self];
+	}
+    }
 }
 
 
@@ -786,7 +857,7 @@
 	  PRScale *scaleFilter;
 	  
 	  scaleFilter = [[PRScale alloc] init];
-	  scaledImage = [scaleFilter scaleImage:srcImage :newW :newH :LINEAR_HV :nil];
+	  scaledImage = [scaleFilter scaleImage:srcImage :newW :newH :BILINEAR :nil];
 	  [scaleFilter release];
 	  scaledImageRep = [NSBitmapImageRep imageRepWithData:[scaledImage TIFFRepresentation]];
 	}
@@ -834,4 +905,31 @@
     }
 }
 
+/* preferences */
+- (IBAction)showPreferences:(id)sender
+{
+  NSUserDefaults *defaults;
+
+  defaults = [NSUserDefaults standardUserDefaults];
+
+  [destroyOrRecycleButton setState:[defaults boolForKey:LM_KEY_DESTROYRECYCLE] ? NSOnState : NSOffState];
+  [askBeforeDeletingButton setState:[defaults boolForKey:LM_KEY_ASKDELETING] ? NSOnState : NSOffState];
+  [prefPanel makeKeyAndOrderFront: sender];
+}
+
+- (IBAction)savePreferences:(id)sender
+{
+  NSUserDefaults *defaults;
+
+  defaults = [NSUserDefaults standardUserDefaults];
+  [defaults setBool:[destroyOrRecycleButton state] forKey:LM_KEY_DESTROYRECYCLE];
+  [defaults setBool:[askBeforeDeletingButton state] forKey:LM_KEY_ASKDELETING];
+  [prefPanel performClose:self];
+}
+
+- (IBAction)cancelPreferences:(id)sender
+{
+  [prefPanel performClose:self];
+}
+
 @end
