@@ -2,7 +2,7 @@
    Project: LaternaMagica
    FileTable.m
 
-   Copyright (C) 2006-2009 Riccardo Mottola
+   Copyright (C) 2006-2012 Riccardo Mottola
 
    Author: Riccardo Mottola
 
@@ -23,8 +23,16 @@
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
+#include <math.h>
+
 #import "FileTable.h"
 
+#ifdef __NetBSD__
+#if __NetBSD_Version__ <= 299000000
+#define lround (long)round
+#endif
+#endif
+
 
 @implementation FileTable
 
@@ -62,6 +70,31 @@
     [filePaths removeObjectAtIndex:index];
 }
 
+- (void)scrambleObjects
+{
+  NSMutableArray *newNames;
+  NSMutableArray *newPaths;
+  
+  newNames = [NSMutableArray arrayWithCapacity: [fileNames count]];
+  newPaths = [NSMutableArray arrayWithCapacity: [filePaths count]];
+  while ([fileNames count] > 0)
+    {
+      unsigned i;
+      
+      /* get a rescaled random number */
+      i = (unsigned)lround(((double)(unsigned long)random() / RAND_MAX) * ([fileNames count]-1));
+      [newNames addObject: [fileNames objectAtIndex: i]];
+      [fileNames removeObjectAtIndex: i];
+      [newPaths addObject: [filePaths objectAtIndex: i]];
+      [filePaths removeObjectAtIndex: i];
+    }
+  [fileNames release];
+  [filePaths release];
+  
+  fileNames = [newNames retain];
+  filePaths = [newPaths retain];
+}
+
 
 /* methods implemented to follow the informal NSTableView protocol */
 - (int)numberOfRowsInTableView:(NSTableView *)aTableView
