@@ -2,7 +2,7 @@
    Project: LaternaMagica
    LMFlipView.m
 
-   Copyright (C) 2006-2010 Riccardo Mottola
+   Copyright (C) 2006-2011 Riccardo Mottola
 
    Author: Riccardo Mottola
 
@@ -26,15 +26,12 @@
 #import "LMFlipView.h"
 #import "AppController.h"
 
-#ifdef GNUSTEP
-#define KC_ESCAPE 9
-#define KC_LEFTARROW 100
-#define KC_RIGHTARROW 102
-#else
-#define KC_ESCAPE 53
-#define KC_LEFTARROW 123
-#define KC_RIGHTARROW 124
-#endif
+/* we define our own constants */
+enum
+{
+  NSEscapeCharacter = 0x001b,
+  NSSpaceCharacter = 0x0020
+};
 
 @implementation LMFlipView
 
@@ -53,7 +50,10 @@
 /** respond to key equivalents which are not bound do menu items */
 -(BOOL)performKeyEquivalent: (NSEvent*)theEvent
 {
-    unsigned short keyCode;
+  NSString *keyStr;
+  unichar keyCh;
+  unsigned int modifierFlags;
+
 #ifdef __APPLE__
 /* Apple is definitively broken here and on all versions tested it returns for the arrow key
     also a KeyUp event, which it should not, as the Event is specified to be keyDown */
@@ -61,24 +61,37 @@
         return [super performKeyEquivalent:theEvent];
 #endif
 
-    keyCode = [theEvent keyCode];
-    if (keyCode == KC_ESCAPE)
+    keyCh = 0x0;
+    keyStr = [theEvent characters];
+    if ([keyStr length] > 0)
+      keyCh = [keyStr characterAtIndex:0];
+    modifierFlags = [theEvent modifierFlags];
+
+    if (keyCh == NSEscapeCharacter)
       {
-        NSLog(@"(keyCode) Escape!");
         [controller setFullScreen:theEvent];
         return YES;
       }
-    else if (keyCode == KC_LEFTARROW)
+    else if (keyCh == NSLeftArrowFunctionKey || keyCh == NSUpArrowFunctionKey)
       {
         [controller prevImage:theEvent];
         return YES;
       }
-    else if (keyCode == KC_RIGHTARROW)
+    else if (keyCh == NSRightArrowFunctionKey || keyCh == NSDownArrowFunctionKey || keyCh == NSSpaceCharacter)
       {
         [controller nextImage:theEvent];
         return YES;
       }
-    NSLog(@"keyCode %d", keyCode);    
+    else if (keyCh == NSDeleteFunctionKey || keyCh == NSDeleteCharacter)
+      {
+	if (modifierFlags & NSShiftKeyMask)
+	  [controller removeImage:theEvent];
+	else
+	  [controller eraseImage:theEvent];
+        return YES;
+      }
+    else
+      NSLog(@"keyCh %x", keyCh);    
     return [super performKeyEquivalent:theEvent];
 }
 
